; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Shadow Motions |------------------------------------------------------
[Command]
name = "ShadowFireball"
command = ~D, DF, F, ~z
time = 30

[Command]
name = "ShadowFireball"
command = D, DF, F, ~z
time = 30

[Command]
name = "ShadowFireball"
command = ~D, DF, F, ~y
time = 30

[Command]
name = "ShadowFireball"
command = D, DF, F, ~y
time = 30

[Command]
name = "ShadowFireball"
command = ~D, DF, F, ~x
time = 30

[Command]
name = "ShadowFireball"
command = D, DF, F, ~x
time = 30

[Command]
name = "LeapShadow"
command = ~B, F, ~a
time = 20

[Command]
name = "LeapShadow"
command = ~B, F, ~b
time = 20

[Command]
name = "LeapShadow"
command = ~B, F, ~c
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "Dash"
command = ~B, F, x
time = 15

[Command]
name = "SlowFireball"
command = ~D, DF, F, x
time = 25

[Command]
name = "MediumFireball"
command = ~D, DF, F, y
time = 25

[Command]
name = "FastFireball"
command = ~D, DF, F, z
time = 25

[Command]
name = "Golf"
command = ~B, F, z
time = 15

[Command]
name = "LeapFwd"
command = ~B, F, a
time = 15

[Command]
name = "LeapUp"
command = ~B, F, b
time = 15

[Command]
name = "LeapBack"
command = ~B, F, c
time = 15

[Command]
name = "Charge_Golf"
command = ~15$B, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, F+z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, D, F+z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, U, F+z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, D, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, DB, D, DF, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, DB, D, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, D, DF, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, U, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, UB, U, UF, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, UB, U, F, z
time = 30

[Command]
name = "Charge_Golf"
command = ~15$B, U, UF, F, z
time = 30

[Command]
name = "UltImpale"
command = ~15$B, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, F+a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, D, F+a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, U, F+a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, D, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, DB, D, DF, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, DB, D, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, D, DF, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, U, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, UB, U, UF, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, UB, U, F, a
time = 30

[Command]
name = "UltImpale"
command = ~15$B, U, UF, F, a
time = 30

[Command]
name = "Impale"
command = ~B, F, F, y
time = 30

[Command]
name = "UltScreenSmack"
command = ~F, D, B, x
time = 25

[Command]
name = "UltScreenSmack"
command = ~F, DF, D, DB, B, x
time = 30

[Command]
name = "ScreenSmack"
command = ~B, D, F, b
time = 25

[Command]
name = "ScreenSmack"
command = ~B, DB, D, DF, F, b
time = 30

[Command]
name = "Humiliate"
command = ~D, D, F, F, a
time = 35

[Command]
name = "Ultra"
command = ~15$B, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, F+c
time = 30

[Command]
name = "Ultra"
command = ~15$B, D, F+c
time = 30

[Command]
name = "Ultra"
command = ~15$B, U, F+c
time = 30

[Command]
name = "Ultra"
command = ~15$B, D, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, DB, D, DF, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, DB, D, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, D, DF, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, U, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, UB, U, UF, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, UB, U, F, c
time = 30

[Command]
name = "Ultra"
command = ~15$B, U, UF, F, c
time = 30

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Combo Breakers |-----------------------------------------------------------
[Command]
name = "ComboBreak1"
command = ~B, F, x
time = 20

[Command]
name = "ComboBreak2"
command = ~B, F, y
time = 20

[Command]
name = "ComboBreak3"
command = ~B, F, z
time = 20

[Command]
name = "EnemyBreak1"
command = ~B, F, x
time = 30

[Command]
name = "EnemyBreak2"
command = ~B, F, y
time = 30

[Command]
name = "EnemyBreak3"
command = ~B, F, z
time = 30

[Command]
name = "EnemyBreak1"
command = ~B, F, a
time = 30

[Command]
name = "EnemyBreak2"
command = ~B, F, b
time = 30

[Command]
name = "EnemyBreak3"
command = ~B, F, c
time = 30

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holdstart";Required (do not remove)
command = /$s
time = 1

;-| Escape Mashers |--------------------------------------------------------------
; These commands are used for mashing by P2 to escape dangemode.

[Command]
name = "EscA"
command = ~a
time = 1

[Command]
name = "EscB"
command = ~b
time = 1

[Command]
name = "EscC"
command = ~c
time = 1

[Command]
name = "EscX"
command = ~x
time = 1

[Command]
name = "EscY"
command = ~y
time = 1

[Command]
name = "EscZ"
command = ~z
time = 1

[Command]
name = "EscStart"
command = ~s
time = 1

[Command]
name = "EscF"
command = ~F
time = 1

[Command]
name = "EscB"
command = ~B
time = 1

[Command]
name = "EscU"
command = ~U
time = 1

[Command]
name = "EscD"
command = ~D
time = 1

;-| AI Commands |--------------------------------------------------------------
; These dummy commands activate the AI

;-| CPU ONLY (DUMMY MOVES ONLY THE COMPUTER CAN DO THAT ACTIVATE HIS AI |-----------------------
[Command]
name = "CPU1"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU2"
command = D, U, U, D, D, U
time = 1

[Command]
name = "CPU3"
command = D, D, D, U, U, U
time = 1

[Command]
name = "CPU4"
command = U, D, D, U, U, U
time = 1

[Command]
name = "CPU5"
command = D, D, U, U, D, D
time = 1

[Command]
name = "CPU6"
command = U, D, D, D, D, U
time = 1

[Command]
name = "CPU7"
command = U, U, U, U, U, D
time = 1

[Command]
name = "CPU8"
command = U, U, U, U, D, U
time = 1

[Command]
name = "CPU9"
command = U, U, U, D, U, U
time = 1

[Command]
name = "CPU10"
command = U, U, D, U, U, U
time = 1

[Command]
name = "CPU11"
command = U, D, U, U, U, U
time = 1

[Command]
name = "CPU12"
command = D, U, D, U, D, U
time = 1

[Command]
name = "CPU13"
command = U, U, D, U, U, U, U
time = 1

[Command]
name = "CPU14"
command = U, D, D, U, U, U, U
time = 1

[Command]
name = "CPU15"
command = D, U, D, U, U, U, D
time = 1

[Command]
name = "CPU16"
command = D, D, D, U, U, U, U
time = 1

[Command]
name = "CPU17"
command = U, U, D, U, U, D, D
time = 1

[Command]
name = "CPU18"
command = D, D, D, U, D, D, D
time = 1

[Command]
name = "CPU19"
command = U, D, D, U, D, U, D
time = 1

[Command]
name = "CPU20"
command = D, D, D, U, U, U, D
time = 1

[Command]
name = "CPU21"
command = U, D, U, D, U, U, U
time = 1

[Command]
name = "CPU22"
command = U, U, U, U, U, U, U
time = 1

[Command]
name = "CPU23"
command = D, D, D, D, D, D, D
time = 1

[Command]
name = "CPU24"
command = D, D, D, D, D, D, U
time = 1

[Command]
name = "CPU25"
command = D, D, D, D, D, U, D
time = 1

[Command]
name = "CPU26"
command = D, D, U, U, D, U
time = 1

[Command]
name = "CPU27"
command = D, U, U, D, D, U
time = 1

[Command]
name = "CPU28"
command = D, D, D, U, U, U
time = 1

[Command]
name = "CPU29"
command = U, D, D, U, U, U
time = 1

[Command]
name = "CPU30"
command = D, D, U, U, D, D
time = 1

[Command]
name = "CPU31"
command = U, D, D, D, D, U
time = 1

[Command]
name = "CPU32"
command = U, U, U, U, U, D
time = 1

[Command]
name = "CPU33"
command = U, U, U, U, D, U
time = 1

[Command]
name = "CPU34"
command = U, U, U, D, U, U
time = 1

[Command]
name = "CPU35"
command = U, U, D, U, U, U
time = 1

[Command]
name = "CPU36"
command = U, D, U, U, U, U
time = 1

[Command]
name = "CPU37"
command = D, U, D, U, D, U
time = 1

[Command]
name = "CPU38"
command = U, U, D, U, U, U, U
time = 1

[Command]
name = "CPU39"
command = U, D, D, U, U, U, U
time = 1

[Command]
name = "CPU40"
command = D, U, D, U, U, U, D
time = 1

[Command]
name = "CPU41"
command = D, D, D, U, U, U, U
time = 1

[Command]
name = "CPU42"
command = U, U, D, U, U, D, D
time = 1

[Command]
name = "CPU43"
command = D, D, D, U, D, D, D
time = 1

[Command]
name = "CPU44"
command = U, D, D, U, D, U, D
time = 1

[Command]
name = "CPU45"
command = D, D, D, U, U, U, D
time = 1

[Command]
name = "CPU46"
command = U, D, U, D, U, U, U
time = 1

[Command]
name = "CPU47"
command = U, U, U, U, U, U, U
time = 1

[Command]
name = "CPU48"
command = D, D, D, D, D, D, D
time = 1

[Command]
name = "CPU49"
command = D, D, D, D, D, D, U
time = 1

[Command]
name = "CPU50"
command = D, D, D, D, D, U, D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -1, AITurnOn]
type = VarSet
triggerall = var(2) != 1
trigger1  = command = "CPU1"
trigger2  = command = "CPU2"
trigger3  = command = "CPU3"
trigger4  = command = "CPU4"
trigger5  = command = "CPU5"
trigger6  = command = "CPU6"
trigger7  = command = "CPU7"
trigger8  = command = "CPU8"
trigger9  = command = "CPU9"
trigger10 = command = "CPU10"
trigger11 = command = "CPU11"
trigger12 = command = "CPU12"
trigger13 = command = "CPU13"
trigger14 = command = "CPU14"
trigger15 = command = "CPU15"
trigger16 = command = "CPU16"
trigger17 = command = "CPU17"
trigger18 = command = "CPU18"
trigger19 = command = "CPU19"
trigger20 = command = "CPU20"
trigger21 = command = "CPU21"
trigger22 = command = "CPU22"
trigger23 = command = "CPU23"
trigger24 = command = "CPU24"
trigger25 = command = "CPU25"
trigger26 = Alive && !IsHelper
trigger26 = IsHomeTeam
trigger26 = TeamSide = 2 || MatchNo > 1
trigger27  = command = "CPU26"
trigger28  = command = "CPU27"
trigger29  = command = "CPU28"
trigger30  = command = "CPU29"
trigger31  = command = "CPU30"
trigger32  = command = "CPU31"
trigger33  = command = "CPU32"
trigger34  = command = "CPU33"
trigger35  = command = "CPU34"
trigger36 = command = "CPU35"
trigger37 = command = "CPU36"
trigger38 = command = "CPU37"
trigger39 = command = "CPU38"
trigger40 = command = "CPU39"
trigger41 = command = "CPU40"
trigger42 = command = "CPU41"
trigger43 = command = "CPU42"
trigger44 = command = "CPU43"
trigger45 = command = "CPU44"
trigger46 = command = "CPU45"
trigger47 = command = "CPU46"
trigger48 = command = "CPU47"
trigger49 = command = "CPU48"
trigger50 = command = "CPU49"
trigger51 = command = "CPU50"
v = 2
value = 1

;;===========================================================================
;;---------------------------------------------------------------------------
;;Smash Kung Fu Upper (uses one super bar)
;[State -1, Smash Kung Fu Upper]
;type = ChangeState
;value = 3050
;triggerall = command = "SmashKFUpper"
;triggerall = power >= 1000
;triggerall = statetype != A
;trigger1 = ctrl
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3050,3100)
;trigger2 = movecontact

;;---------------------------------------------------------------------------
;;Triple Kung Fu Palm (uses one super bar)
;[State -1, Triple Kung Fu Palm]
;type = ChangeState
;value = 3000
;triggerall = command = "TripleKFPalm"
;triggerall = power >= 1000
;trigger1 = statetype = S
;trigger1 = ctrl
;trigger2 = statetype != A
;trigger2 = hitdefattr = SC, NA, SA, HA
;trigger2 = stateno != [3000,3050)
;trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.

;[State -1, Combo condition Reset]
;type = VarSet
;trigger1 = 1
;var(1) = 0

;[State -1, Combo condition Check]
;type = VarSet
;trigger1 = statetype != A
;trigger1 = ctrl
;trigger2 = (stateno = [200,299]) || (stateno = [400,499])
;trigger2 = stateno != 440 ;Except for sweep kick
;trigger2 = movecontact
;var(1) = 1


;===============================================================================================
;===============================================================================================
;Combo Link/Ender Buffers. Makes the timing on Eyedol's various combo 
;chains a bit more liberal. When one of these VARs are set, he will
;automaticly use the proper ender.
;===============================================================================================
;===============================================================================================
[State -1, UltScreenSmack Check]
type = VarSet
triggerall = command = "UltScreenSmack"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 17

[State -1, UltImpale Check]
type = VarSet
triggerall = command = "UltImpale"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 16 ;var(30)

[State -1, Ultra Check]
type = VarSet
triggerall = command = "Ultra"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 15 ;var(30)

[State -1, Shadow Leap Ender Check]
type = VarSet
triggerall = command = "LeapShadow"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 14

[State -1, Charged Golf Club Ender Check]
type = VarSet
triggerall = command = "Charge_Golf"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 13

[State -1, Golf Club Ender Check]
type = VarSet
triggerall = command = "Golf"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 10

[State -1, Dash Ender Check]
type = VarSet
triggerall = command = "Dash"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 11

[State -1, Leap Ender Check]
type = VarSet
triggerall = command = "LeapFwd" || command = "LeapUp" || command = "LeapBack"
triggerall = var(10) = 0
trigger1 = stateno = 2000
trigger1 = time > 15
trigger2 = stateno = 2001
trigger2 = time > 15
trigger3 = stateno = 2002
trigger3 = time > 5
trigger4 = stateno = 2003
trigger4 = time > 5
var(10) = 12

;===============================================================================================
;===============================================================================================
; Combo Systems Varibles. VARs 30-39 cover the KI combo system, each gets
; set when the player is able to perform a certain combo link. They start
; at 26, then count down to 0, disabling that combo again.
;===============================================================================================
;===============================================================================================
;Most of the combo states add +1 to Var 30 at their beginning.
;Var 30 manages damage control and keep infinite chains from working.
;This state reset var 30 when the comboing is done, P1 has control and
;P2 is no longer in a hit state.
[State -1, Combo Tab Keeper End]
type = VarSet
triggerall = ctrl = 1 || stateno = 1000
triggerall = p2movetype != H || p2stateno = 5120
trigger1 = var(31) = 0
trigger1 = var(32) = 0
trigger1 = var(33) = 0
trigger1 = var(34) = 0
trigger1 = var(35) = 0
trigger1 = var(36) = 0
trigger1 = var(37) = 0
trigger1 = var(38) = 0
trigger1 = var(39) = 0
var(30) = 0

[State -1, Medium Kick Combo Countdown]
type = VarAdd
trigger1 = var(31) > 0
var(31) = -1

[State -1, Strong Punch Combo Countdown]
type = VarAdd
trigger1 = var(32) > 0
var(32) = -1

[State -1, Strong Kick Combo Countdown]
type = VarAdd
trigger1 = var(33) > 0
var(33) = -1

[State -1, Medium Punch Combo Countdown]
type = VarAdd
trigger1 = var(34) > 0
var(34) = -1

[State -1, Light Punch Combo Countdown]
type = VarAdd
trigger1 = var(35) > 0
var(35) = -1

[State -1, Light Kick Combo Countdown]
type = VarAdd
trigger1 = var(36) > 0
var(36) = -1

[State -1, Charged Golf Club Countdown]
type = VarAdd
trigger1 = var(37) > 0
var(37) = -1

[State -1, ClubJuggleVar]
type = VarSet
triggerall = movehit = 1
trigger1 = stateno = 1020
trigger2 = stateno = 2900
var(1) = var(30) + 2

[State -1, Medium Kick Combo Set]
type = VarSet
trigger1 = stateno = 1002
trigger1 = movehit = 1
trigger1 = var(30) < 2
trigger2 = stateno = 260 || stateno = 261
trigger2 = movehit = 1
trigger3 = stateno = 420
trigger3 = movehit = 1
var(31) = 16

[State -1, Strong Punch Combo Set]
type = VarSet
trigger1 = stateno = 1002
trigger1 = movehit = 1
trigger1 = var(30) < 2
trigger2 = stateno = 240 || stateno = 241
trigger2 = movehit = 1
trigger3 = stateno = 400
trigger3 = movehit = 1
var(32) = 16

[State -1, Strong Kick Combo Set]
type = VarSet
trigger1 = stateno = 52
trigger1 = movehit = 1
trigger2 = stateno = 210
trigger2 = movehit = 1
trigger3 = stateno = 400
trigger3 = movehit = 1
var(33) = 16

[State -1, Medium Punch Combo Set]
type = VarSet
trigger1 = stateno = 420
trigger1 = movehit = 1
var(34) = 16

[State -1, Light Punch Combo Set]
type = VarSet
trigger1 = stateno = 230
trigger1 = movehit = 1
trigger2 = stateno = 410
trigger2 = movehit = 1
var(35) = 16 ;22

[State -1, Light Kick Combo Set]
type = VarSet
trigger1 = stateno = 200 || stateno = 201
trigger1 = movehit = 1
trigger2 = stateno = 410
trigger2 = movehit = 1
var(36) = 16 ;22

[State -1, Charged Golf Club Combo Set]
type = VarSet
trigger1 = stateno = 2000
trigger1 = movehit = 1
trigger1 = stateno = 2001
trigger1 = movehit = 1
trigger1 = stateno = 2002
trigger1 = movehit = 1
trigger1 = stateno = 2003
trigger1 = movehit = 1
var(37) = 16

[State -1, ComboBreaker On Countdown]
type = VarAdd
trigger1 = var(44) > 0
var(44) = -1

[State -1, ComboBreaker Ender]
type = VarSet
trigger1 = var(44) = 21
trigger2 = var(44) = 42
var(44) = 0

[State -1, ComboBreakerVarSetLight]
type = VarSet
triggerall = command = "ComboBreak1"
trigger1 = stateno = [5000,5029]
trigger2 = stateno = [5070,5089]
trigger3 = stateno = [5030,5069] 
trigger3 = vel Y <= 0
var(44) = 20

[State -1, ComboBreakerVarSetMedium]
type = VarSet
triggerall = command = "ComboBreak2"
trigger1 = stateno = [5000,5029]
trigger2 = stateno = [5070,5089]
trigger3 = stateno = [5030,5069] 
trigger3 = vel Y <= 0
var(44) = 41

[State -1, ComboBreakerVarSetHeavy]
type = VarSet
triggerall = command = "ComboBreak3"
trigger1 = stateno = [5000,5029]
trigger2 = stateno = [5070,5089]
trigger3 = stateno = [5030,5069] 
trigger3 = vel Y <= 0
var(44) = 62

;THE SAD, BROKEN REMAINS OF MY UNIVERSAL COMBO BREAKER'S COMMAND INPUT.
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

;[State -1, EnemyComboBreaker On Countdown]
;type = VarAdd
;trigger1 = var(51) > 0
;var(51) = -1

;[State -1, EnemyComboBreaker Ender]
;type = VarSet
;trigger1 = var(51) = 31
;trigger2 = var(51) = 62
;var(51) = 0

;[State -1, EnemyComboBreakerVarSetLight]
;type = VarSet
;trigger1 = enemynear(0),command = "FF"
;;;trigger1 = enemy,command = "EnemyBreak1"
;var(51) = 30

;[State -1, EnemyComboBreakerVarSetMedium]
;type = VarSet
;trigger1 = enemynear,command = "BB"
;;;trigger1 = enemy,command = "EnemyBreak2"
;var(51) = 61

;[State -1, EnemyComboBreakerVarSetHeavy]
;type = VarSet
;trigger1 = enemynear,command = "recovery"
;;trigger1 = enemy,command = "z"
;;trigger2 = enemy,command = "c"
;;;trigger1 = enemy,command = "EnemyBreak3"
;var(51) = 92

;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
;<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<

;===============================================================================================
;===============================================================================================
; Special and normal moves
;===============================================================================================
;===============================================================================================
;---------------------------------------------------------------------------
;---------------------------------------------------------------------------
;ULTIMATE IMPALE!
[State -1, ULTIMPALE]
type = ChangeState
value = 2910
triggerall = var(2) != 1
triggerall = stateno != 2910
triggerall = p2life <= 250 && p2life > 0
triggerall = var(9) >= 1 || teammode = turns
triggerall = command = "UltImpale" || var(10) = 16
triggerall = movetype != H
trigger1 = stateno = 2000
trigger1 = time > 27
trigger2 = stateno = 2001
trigger2 = time > 38
trigger3 = stateno = 2002
trigger3 = time > 23
trigger4 = stateno = 2003
trigger4 = time > 25

;ULTIMATE SCREENSMACK!
[State -1, ULTSCREENSMACK]
type = ChangeState
value = 2920
triggerall = var(2) != 1
triggerall = stateno != 2910
triggerall = p2life <= 250 && p2life > 0
triggerall = var(9) >= 1 || teammode = turns
triggerall = command = "UltScreenSmack" || var(10) = 17
triggerall = movetype != H
trigger1 = stateno = 2000
trigger1 = time > 27
trigger2 = stateno = 2001
trigger2 = time > 38
trigger3 = stateno = 2002
trigger3 = time > 23
trigger4 = stateno = 2003
trigger4 = time > 25

;ULTRA COMBO!!!
;Var(19) is just for laughs for Eyedol.
[State -1, ULTRA1]
type = ChangeState
value = 2900
triggerall = var(2) != 1
triggerall = stateno != 2900
triggerall = p2life <= 250 && p2life > 0 || var(19) > 0
triggerall = var(9) >= 1 || teammode = turns || var(19) > 0
triggerall = command = "Ultra" || var(10) = 15
triggerall = movetype != H
trigger1 = stateno = 2000
trigger1 = time > 27
trigger2 = stateno = 2001
trigger2 = time > 38
trigger3 = stateno = 2002
trigger3 = time > 23
trigger4 = stateno = 2003
trigger4 = time > 25

;Charged Golf Club Combo
[State -1, ChargeGolf]
type = ChangeState
value = 2004
triggerall = stateno != 2004
;triggerall = var(37) > 0
triggerall = command = "Charge_Golf" || var(10) = 13
triggerall = movetype != H
trigger1 = stateno = 2000
trigger1 = time > 27
trigger2 = stateno = 2001
trigger2 = time > 38
trigger3 = stateno = 2002
trigger3 = time > 23
trigger4 = stateno = 2003
trigger4 = time > 25

;Strong Punch/Kick Combo
[State -1, SPKCombo]
type = ChangeState
value = 2001
triggerall = stateno != [2000,2999]
triggerall = movetype != H
trigger1 = command = "z"
trigger1 = var(32) > 0
trigger2 = command = "c"
trigger2 = var(33) > 0

;---------------------------------------------------------------------------
;Meduim Kick Combo
[State -1, MKCombo]
type = ChangeState
value = 2000
triggerall = stateno != [2000,2999]
triggerall = movetype != H
trigger1 = command = "b"
trigger1 = var(31) > 0
trigger2 = command = "y"
trigger2 = var(34) > 0

;---------------------------------------------------------------------------
;Light Punch Combo
[State -1, MKCombo]
type = ChangeState
value = 2002
triggerall = stateno != [2000,2999]
triggerall = movetype != H
trigger1 = command = "x"
trigger1 = var(35) > 0

;---------------------------------------------------------------------------
;Light Kick Combo
[State -1, MKCombo]
type = ChangeState
value = 2003
triggerall = stateno != [2000,2999]
triggerall = movetype != H
trigger1 = command = "a"
trigger1 = var(36) > 0

;---------------------------------------------------------------------------
;Humiliation
[State -1, Humiliation]
type = ChangeState
value = 2990
triggerall = p2stateno = 9999
triggerall = p2bodydist X >= 64
triggerall = movetype != H
triggerall = Pos Y = 0
triggerall = command = "Humiliate"
trigger1 = ctrl = 1
trigger1 = teammode = turns
trigger1 = life > (lifemax/2)
trigger2 = ctrl = 1
trigger2 = var(5) >= 2

;---------------------------------------------------------------------------
;Impale No Mercy
[State -1, Impale]
type = ChangeState
value = 2910
triggerall = p2stateno = 9999
triggerall = p2bodydist X <= 64
triggerall = movetype != H
triggerall = Pos Y = 0
trigger1 = command = "Impale"
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Screen Smack No Mercy
[State -1, ScreenSmack]
type = ChangeState
value = 2920
triggerall = p2stateno = 9999
triggerall = p2bodydist X <= 48
triggerall = movetype != H
triggerall = Pos Y = 0
trigger1 = command = "ScreenSmack"
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Shadow Move Leap
[State -1, ShadowLeap]
type = ChangeState
value = 1900
triggerall = var(49) > 0
triggerall = movetype != H
trigger1 = command = "LeapShadow"
trigger1 = ctrl = 1
trigger2 = command = "LeapShadow" || var(10) = 14
trigger2 = stateno = 2000
trigger2 = time > 27
trigger3 = command = "LeapShadow" || var(10) = 14
trigger3 = stateno = 2001
trigger3 = time > 38
trigger4 = command = "LeapShadow" || var(10) = 14
trigger4 = stateno = 2002
trigger4 = time > 23
trigger5 = command = "LeapShadow" || var(10) = 14
trigger5 = stateno = 2003
trigger5 = time > 25

;---------------------------------------------------------------------------
;Shadow Move Triple Fireball
[State -1, ShadowTripleFireball]
type = ChangeState
value = 1910
triggerall = movetype != H
triggerall = var(49) > 0
trigger1 = command = "ShadowFireball"
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Golf Club Swing (normal speed)
[State -1, GolfClub]
type = ChangeState
value = 1020
triggerall = movetype != H
trigger1 = command = "Golf"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 1001 || stateno = 1003
trigger2 = command = "holdback"
trigger2 = command = "z"
trigger3 = command = "Golf" || var(10) = 10
trigger3 = stateno = 2000
trigger3 = time > 27
trigger4 = command = "Golf" || var(10) = 10
trigger4 = stateno = 2001
trigger4 = time > 38
trigger5 = command = "Golf" || var(10) = 10
trigger5 = stateno = 2002
trigger5 = time > 23
trigger6 = command = "Golf" || var(10) = 10
trigger6 = stateno = 2003
trigger6 = time > 25

;---------------------------------------------------------------------------
;Stomping Stance
[State -1, StompStance]
triggerall = movetype != H
type = ChangeState
value = 1000
triggerall = movetype != H
triggerall = command = "y"
triggerall = command = "holdback"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Dash Attack (fast speed)
[State -1, FastDash]
type = ChangeState
value = 1003
triggerall = movetype != H
trigger1 = command = "Dash"
trigger1 = stateno = 1000
trigger2 = command = "Dash" || var(10) = 11
trigger2 = stateno = 2000
trigger2 = time > 27
trigger3 = command = "Dash" || var(10) = 11
trigger3 = stateno = 2001
trigger3 = time > 38
trigger4 = command = "Dash" || var(10) = 11
trigger4 = stateno = 2002
trigger4 = time > 23
trigger5 = command = "Dash" || var(10) = 11
trigger5 = stateno = 2003
trigger5 = time > 25
trigger6 = command = "Dash"
trigger6 = ctrl = 1
trigger6 = var(1) > 2
trigger7 = var(2) = 1 && var(3) = [1,50]
trigger7 = random <= 75
trigger7 = stateno = 1000 || stateno = 195
trigger7 = p2stateno != [5030,5199]

;---------------------------------------------------------------------------
;Dash Attack (normal speed)
[State -1, Dash]
type = ChangeState
value = 1001
triggerall = movetype != H
triggerall = command = "Dash"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = hitcount < 3
trigger2 = movehit = 1
trigger2 = stateno = 1002

;---------------------------------------------------------------------------
;Dash Cancel
[State -1, DashCancel]
type = ChangeState
value = 1004
triggerall = movetype != H
triggerall = stateno = 1001 || stateno = 1003
trigger1 = command = "holdback"
trigger1 = command = "x"


;---------------------------------------------------------------------------
;Triple Fireball
[State -1, TripleFireball]
type = ChangeState
value = 1014
triggerall = movetype != H
trigger1 = command = "FastFireball"
trigger1 = stateno = 1000
trigger2 = var(2) = 1 && var(3) = [51,99]
trigger2 = random <= 75
trigger2 = stateno = 1000 || stateno = 195
trigger2 = p2stateno != [5030,5199]

;---------------------------------------------------------------------------
;Slow Fireball
[State -1, SlowFireball]
type = ChangeState
value = 1010
triggerall = movetype != H
trigger1 = command = "SlowFireball"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Medium Fireball
[State -1, SlowFireball]
type = ChangeState
value = 1012
triggerall = movetype != H
trigger1 = command = "MediumFireball"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Fast Fireball
[State -1, FastFireball]
type = ChangeState
value = 1013
triggerall = movetype != H
trigger1 = command = "FastFireball"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Foward Leap
[State -1, LeapForward]
type = ChangeState
value = 490
triggerall = movetype != H
trigger1 = command = "LeapFwd"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 1001 || stateno = 1003
trigger2 = command = "holdback"
trigger2 = command = "a"
trigger3 = command = "LeapFwd" || var(10) = 12
trigger3 = stateno = 2000
trigger3 = time > 27
trigger4 = command = "LeapFwd" || var(10) = 12
trigger4 = stateno = 2001
trigger4 = time > 38
trigger5 = command = "LeapFwd" || var(10) = 12
trigger5 = stateno = 2002
trigger5 = time > 23
trigger6 = command = "LeapFwd" || var(10) = 12
trigger6 = stateno = 2003
trigger6 = time > 25

;---------------------------------------------------------------------------
;Upward Leap
[State -1, LeapUp]
type = ChangeState
value = 491
triggerall = var(2) != 1
triggerall = movetype != H
trigger1 = command = "LeapUp"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = command = "LeapUp" || var(10) = 12
trigger2 = stateno = 2000
trigger2 = time > 27
trigger3 = command = "LeapUp" || var(10) = 12
trigger3 = stateno = 2001
trigger3 = time > 38
trigger4 = command = "LeapUp" || var(10) = 12
trigger4 = stateno = 2002
trigger4 = time > 23
trigger5 = command = "LeapUp" || var(10) = 12
trigger5 = stateno = 2003
trigger5 = time > 25

;---------------------------------------------------------------------------
;Backward Leap
[State -1, LeapBackward]
type = ChangeState
value = 492
triggerall = var(2) != 1
triggerall = movetype != H
triggerall = command = "LeapBack"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = command = "LeapBack" || var(10) = 12
trigger2 = stateno = 2000 || var(12) > 0
trigger2 = time > 27
trigger3 = command = "LeapBack" || var(10) = 12
trigger3 = stateno = 2001
trigger3 = time > 38
trigger4 = command = "LeapBack" || var(10) = 12
trigger4 = stateno = 2002
trigger4 = time > 23
trigger5 = command = "LeapBack" || var(10) = 12
trigger5 = stateno = 2003
trigger5 = time > 25

;;===========================================================================
;;---------------------------------------------------------------------------
;;Run Fwd
;[State -1, Run Fwd]
;type = ChangeState
;value = 100
;trigger1 = command = "FF"
;trigger1 = statetype = S
;trigger1 = ctrl

;;---------------------------------------------------------------------------
;;Run Back
;[State -1, Run Back]
;type = ChangeState
;value = 105
;trigger1 = command = "BB"
;trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------
;;Kung Fu Throw
;[State -1, Kung Fu Throw]
;type = ChangeState
;value = 800
;triggerall = command = "y"
;triggerall = statetype = S
;triggerall = ctrl
;triggerall = stateno != 100
;trigger1 = command = "holdfwd"
;trigger1 = p2bodydist X < 3
;trigger1 = (p2statetype = S) || (p2statetype = C)
;trigger1 = p2movetype != H
;trigger2 = command = "holdback"
;trigger2 = p2bodydist X < 5
;trigger2 = (p2statetype = S) || (p2statetype = C)
;trigger2 = p2movetype != H


;===========================================================================
;---------------------------------------------------------------------------
;Second attack trigger
;[State -1, Var1Set]
;type = VarSet
;triggerall = ctrl = 0
;trigger1 = command = "x"
;v = 1
;value = 1

;Stand Light "Punch"
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(2) != 1
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = stateno = 201 && time > 13
trigger3 = stateno = 201
trigger3 = animtime = 0
trigger4 = stateno = 201 && movecontact = 1

[State -1,9]
type = ChangeState
value = 201
triggerall = var(2) != 1
triggerall = command = "x"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = stateno = 200 && time > 15
trigger2 = stateno = 200
trigger2 = animtime = 0
trigger3 = stateno = 200 && movecontact = 1

;---------------------------------------------------------------------------
;Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = var(2) != 1
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Stab
[State -1, Standing Stab]
type = ChangeState
value = 221
triggerall = var(2) != 1
triggerall = command = "z"
triggerall = command = "holdback"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Headbutt (First Part)
[State -1, Standing Headbutt1]
type = ChangeState
value = 260
triggerall = var(2) != 1
triggerall = command = "z"
triggerall = command != "holddown"
triggerall = p2bodydist X < 32
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Headbutt (Second Part)
[State -1, Standing Headbutt1]
type = ChangeState
value = 261
triggerall = var(2) != 1
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = stateno = 260 && time > 16
trigger2 = stateno = 260
trigger2 = animtime = 0

;---------------------------------------------------------------------------
;Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(2) != 1
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = var(2) != 1
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Close-Up Meduim Kick
[State -1, Standing Close Meduim Kick]
type = ChangeState
value = 241
triggerall = var(2) != 1
triggerall = command = "b"
triggerall = command != "holddown"
triggerall = p2bodydist X < 32
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Meduim Kick
[State -1, Standing Meduim Kick]
type = ChangeState
value = 240
triggerall = var(2) != 1
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = 250
triggerall = var(2) != 1
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Life Recover Stomp
[State -1, LifeStomp]
type = ChangeState
value = 195
triggerall = var(2) != 1
triggerall = command = "holdstart"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Attack
[State -1, Crouching Light Attack]
type = ChangeState
value = 400
triggerall = var(2) != 1
triggerall = command = "x" || command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Attack
[State -1, Crouching Medium Attack]
type = ChangeState
value = 410
triggerall = var(2) != 1
triggerall = command = "y" || command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Medium Attack
[State -1, Crouching Medium Attack]
type = ChangeState
value = 420
triggerall = var(2) != 1
triggerall = command = "z" || command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump
[State -1, Jump]
type = ChangeState
value = 41
triggerall = var(2) != 1
triggerall = command = "holdup"
trigger1 = statetype != A
trigger1 = Pos Y >= 0
trigger1 = ctrl

;=====================================================================
;=====================================================================
; BLOOD COLORS
; REMEMBER TO SET ALL BLOOD HELPER to keyctrl = 1 when spawned.
;=====================================================================
;=====================================================================

[State -1, SnowBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Iceman by SH"
trigger2 = p2name = "Iceman"
trigger3 = p2name = "IceMan"
trigger4 = p2name = "Glacius Original"
trigger5 = p2name = "Cactuar"
trigger6 = p2name = "Glacius"
trigger7 = p2name = "FrostMan"
add = 0,224,224
mul = 0,244,244
time = 900
invertall = 1
sinadd = 0,40,40,15
color = 0

[State -1, BlueBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "DARK WARRIOR2"
trigger2 = p2name = "DARK WARRIOR"
trigger3 = p2name = "Dark WarriorMO"
trigger4 = p2name = "Venom"
trigger5 = p2name = "Venon"
trigger6 = p2name = "Venom MVsC"
trigger7 = enemy,selfanimexist(8055032) ;Messatsu's blood detection
add = -255,-255,192
mul = 0,0,192
time = 900
color = 0

[State -1, PurpleBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Rapterrometh"
trigger2 = p2name = "Riptor"
trigger3 = p2name = "Sabrewulf"
trigger4 = p2name = "Ray"
trigger5 = p2name = "Sisi"
trigger6 = p2name = "Piccolo"
trigger7 = p2name = "Thanos"
trigger8 = p2name = "Hauzer"
trigger9 = enemynear,animexist(8055034) ;Messatsu's blood detection
add = 148,-255,118
mul = 148,0,118
time = 900
color = 0

[State -1, LightGreenBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Reptile"
trigger2 = p2name = "ReptileMO"
trigger3 = p2name = "Sheeva"
trigger4 = p2name = "Motaro"
trigger5 = p2name = "Tin's GUNTER"
trigger6 = p2name = "Gunter"
trigger7 = p2name = "Chameleon"
trigger8 = p2name = "Genan"
trigger9 = p2name = "Trident"
trigger10 = p2name = "Rikuo"
trigger11 = p2name = "Picco"
trigger12 = p2name = "MARS PEOPLE"
trigger13 = enemynear,animexist(8055031) ;Messatsu's blood detection
time = 900
mul = 91,122,0
contrast = 183,244,0
add = 183,244,0
color = 0

[State -1, DarkGreenBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Fulgore"
trigger2 = p2name = "BROCKEN"
trigger3 = p2name = "Brocken"
trigger4 = p2name = "Cyber Woo"
trigger5 = p2name = "ZAKU"
trigger6 = p2name = "Zaku"
trigger7 = p2name = "Epyon"
trigger8 = p2name = "Phobos"
trigger9 = p2name = "Silver Horns,by Douglas"
trigger10 = p2name = "GiagantosForSilverHorns"
trigger11 = p2name = "Gundam Wing Zero"
trigger12 = p2name = "Zechs Marquise"
trigger13 = enemynear,animexist(8055038) ;Messatsu's blood detection
mul = 0,82,31
contrast = 0,144,31
add = 0,144,31
color = 0
time = 900

[State -1, YellowBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Yellow Devil"
trigger2 = p2name = "PMatt"
trigger3 = enemy,selfanimexist(8055033) ;Messatsu's blood detection
mul = 200,184,0
contrast = 255,244,0
add = 255,244,0
time = 900
color = 0

[State -1, NoBlood]
type = AssertSpecial;palFX
triggerall = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Post"
trigger2 = p2name = "Scarecrow"
trigger3 = p2name = "Omake: Mr. Wood"
trigger4 = enemy,selfanimexist(8055039) ;Messatsu's blood detection
trigger5 = p2name = "Mercedes Benz"
trigger6 = p2name = "ServBot"
trigger7 = p2name = "Metal Slug Train"
flag = invisible

[State -1, LavaBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "[o_O]'s Blackheart"
trigger2 = p2name = "Blackheart"
trigger3 = p2name = "K'(s)"
trigger4 = p2name = "pyron"
trigger5 = p2name = "Pyron"
trigger6 = p2name = "Cinder"
trigger7 = p2name = "CinderMO"
trigger8 = p2name = "Lucifeller"
trigger9 = enemy,selfanimexist(8055035) ;Messatsu's blood detection
add = 40,-70,-200
sinadd = 50,40,0,15
color = 0
invertall = 1
time = 900

[State -1, PredatorBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Predator"
trigger2 = p2name = "Predator Hunter"
trigger3 = p2name = "Predator Warrior"
trigger4 = p2name = "Predator Chieftan"
trigger5 = p2name = "Predator Warlord"
trigger6 = p2name = "neodio"
trigger7 = p2name = "Abyss Form 2"
add = -128,144,-128
sinadd = 0,-64,0,4
color = 0
invertall = 1
time = 900


[State -1, BlackBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "RoboSmokeMO"
trigger2 = p2name = "RoboSmoke"
trigger3 = p2name = "SektorMO"
trigger4 = p2name = "Sektor"
trigger5 = p2name = "CyraxMO"
trigger6 = p2name = "Cyrax"
trigger7 = p2name = "Dracket"
trigger8 = p2name = "CyraxMO"
trigger9 = p2name = "Nail Bomb"
trigger10 = p2name = "Krang"
trigger11 = p2name = "KrangMO"
trigger12 = p2name = "Sentinel"
trigger13 = p2name = "Apocalypse"
trigger14 = p2name = "elque"
trigger15 = p2name = "Galactus"
trigger16 = p2name = "Onslaught"
trigger17 = p2name = "Fernandeath"
trigger18 = p2name = "Politankz"
trigger19 = p2name = "EMatt"
trigger20 = p2name = "NoobMO"
trigger21 = p2name = "Noob"
trigger22 = p2name = "Noob Saibot"
trigger23 = enemy,selfanimexist(8055036) ;Messatsu's blood detection
trigger24 = p2name = "RoboCop"
trigger25 = p2name = "ED 209"
trigger26 = p2name = "ED-209"
trigger27 = p2name = "RoboCain 2"
trigger28 = p2name = "Alloy"
contrast = 0,0,24
add = -255,-255,48
mul = 0,0,24
time = 900
color = 0

[State -1, TransformerBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "God_Ginrai"
trigger2 = p2name = "Overlord"
trigger3 = p2name = "Fortress_Maximus"
trigger4 = p2name = "Scorponok"
trigger5 = p2name = "Rodimus Prime"
trigger6 = p2name = "Galvatron"
trigger7 = p2name = "Soundwave"
trigger8 = p2name = "Reflector"
trigger9 = p2name = "Chromia"
trigger10 = p2name = "Ironhide"
trigger11 = p2name = "Elita_One"
trigger12 = p2name = "Shockwave"
trigger13 = p2name = "Skywarp"
trigger14 = p2name = "Sunstreaker"
trigger15 = p2name = "Sideswipe"
trigger16 = p2name = "Thundercracker"
trigger17 = p2name = "Starscream"
trigger18 = p2name = "Jazz"
trigger19 = p2name = "Megatron"
trigger20 = p2name = "Optimus Prime"
color = 0
add = 8,-255,16
mul = 8,0,16
time = 900
color = 0

[State -1, WhiteBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "Ickybod Clay"
trigger2 = p2name = "Bonus Kun"
trigger3 = p2name = "BonusKun"
trigger4 = p2name = "Bonuskun"
trigger5 = enemy,selfanimexist(8055037) ;Messatsu's blood detection
time = 900
mul = 244,244,244
contrast = 244,244,244
add = 244,244,244
color = 0

[State -1, MegaManBlood]
type = palFX
triggerall = time = 1
triggerall = Var(59) = 1987
trigger1 = p2name = "MegaMan"
trigger2 = p2name = "Megaman"
trigger3 = p2name = "Mmx"
trigger4 = p2name = "MegaManX"
trigger5 = p2name = "MegamanX"
trigger6 = p2name = "Mega Man X"
trigger7 = p2name = "Zero"
trigger8 = p2name = "Crashman"
trigger9 = p2name = "CutMan"
trigger10 = p2name = "Cutman"
trigger11 = p2name = "Geminiman"
trigger12 = p2name = "Gutsman"
trigger13 = p2name = "HeatmanMO"
trigger14 = p2name = "Protoman"
trigger15 = p2name = "ProtoMan"
trigger16 = p2name = "protoman"
trigger17 = p2name = "Magnetman"
trigger18 = p2name = "MagnetMan"
trigger19 = p2name = "Woodman"
color = 0
add = -255,128,-255
mul = 0,0,128
time = 900
color = 0
